@@ -8,10 +8,9 @@ import subprocess
 
 nlp=""
 matcher=""
-if not util.is_package("es_core_news_md"):
-    subprocess.run("python -m spacy download es_core_news_md")
-    print("...instalando el modelo de leguanje 'es_core_news_md', porfavor vuelva a importar la libreria")
-else:  
+def setup():
+    global nlp
+    global matcher
     nlp = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
     matcher = Matcher(nlp.vocab)
 
@@ -19,9 +18,16 @@ else:
     pattern_2 = [{"POS": "NOUN"}, {"POS": "ADJ"}]
 
     matcher.add("NOUN-de-NOUN", [pattern_1])
-    matcher.add("NOUN-ADJ", [pattern_2])
+    matcher.add("NOUN-ADJ", [pattern_2])   
+    
+if not util.is_package("es_core_news_md"):
+    subprocess.run("python -m spacy download es_core_news_md")
+    print("...instalando el modelo de leguanje 'es_core_news_md', porfavor vuelva a importar la libreria")
+else:
+    setup()
 
 
+ 
 
 
 def get_keywords(dataFrame):
@@ -65,13 +71,13 @@ def group_by_date(dataset, granularity="month"):
         return dataset.groupby(by=["date"])
     
     
-def calculateDist(dataset1,granularity="month"):
-    if "keywords" not in dataset1:
-        get_keywords(dataset1)
-    dataset=dataset1.copy()
-    dataset["month"]=dataset['date'].apply(lambda x: x.split("-")[1])
-    dataset["year"]=dataset['date'].apply(lambda x: x.split("-")[0])
-    gb_dataset=group_by_date(dataset, granularity)
+def calculateDist(dataset,group_by="month"):
+    if "keywords" not in dataset:
+        get_keywords(dataset)
+    dataset_=dataset.copy()
+    dataset_["month"]=dataset_['date'].apply(lambda x: x.split("-")[1])
+    dataset_["year"]=dataset_['date'].apply(lambda x: x.split("-")[0])
+    gb_dataset=group_by_date(dataset_, granularity)
     sophia2_ngram_struct = {}
     if granularity == "day":
         for key, ds in gb_dataset:
